@@ -13,7 +13,7 @@
   packageStartupMessage("**  - Functions and C++ Header Files for Computation on Manifolds.")
   packageStartupMessage("** ")
   packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You (kyoustat@gmail.com)")
+  packageStartupMessage("** Maintainer : Kisung You (kisungyou@outlook.com)")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions with the maintainer.")
   packageStartupMessage("-------------------------------------------------------------------")
